@@ -1,4 +1,4 @@
-# (c) 2003-2017 Vlado Keselj http://web.cs.dal.ca/~vlado
+# (c) 2003-2022 Vlado Keselj http://web.cs.dal.ca/~vlado
 #
 # Text::Ngrams - A Perl module for N-grams processing
 
@@ -12,7 +12,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 %EXPORT_TAGS = ( 'all' => [ qw(new encode_S decode_S) ] );
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 @EXPORT = qw(new);
-$VERSION = '2.005';
+$VERSION = '2.007';
 
 use vars qw($Version);
 $Version = $VERSION;
@@ -29,7 +29,8 @@ sub new {
 
   $self->{windowsize} = exists($params{windowsize}) ?
       $params{windowsize} : 3;
-  die "nonpositive window size: $self->{windowsize}" unless $self->{windowsize} > 0;
+  die "nonpositive window size: $self->{windowsize}"
+    unless $self->{windowsize} > 0;
   delete($params{windowsize});
 
   if (! exists($params{type}) or $params{type} eq 'character') {
@@ -46,28 +47,32 @@ sub new {
                              |[\x00-\xFF])/x;
       $self->{processtoken} = '';
   }
-  #MJ ->
-  #this type is analogous to the "character" type but defined for utf8 characters
+  # MJ ->
+  # This type is analogous to the "character" type but defined for the utf8
+  # characters
   elsif ($params{type} eq 'utf8_character') {
-      #$self->{inputlayer}        
-      #input layer to be put on the input stream by the function binmode before reading from a given stream
-      #and to be removed by ***binmode HANDLE,":pop"*** after the reading from the particular stream is done
-      #has to be a real layer (like ":encoding(utf8)"), not a pseudo layer (like ":utf8")
-      #so that the psuedo layer ":pop" is able to remove this input layer 
-      
-      $self->{inputlayer}=':encoding(utf8)';
-      #this will automatically decode input text from utf8 into Perl internal reporesentation of Unicode strings
-      #and so the regular expressions for Unicode as well as the uc function can be performed on them
+    # $self->{inputlayer}
+    # input layer to be put on the input stream by the function binmode
+    # before reading from a given stream and to be removed by
+    # ***binmode HANDLE,":pop"*** after the reading from the particular
+    # stream is done has to be a real layer (like ":encoding(utf8)"), not a
+    # pseudo layer (like ":utf8") so that the psuedo layer ":pop" is able to
+    # remove this input layer 
       
+    $self->{inputlayer} = ':encoding(utf8)';
+    # this will automatically decode input text from utf8 into Perl internal
+    # reporesentation of Unicode strings and so the regular expressions for
+    # Unicode as well as the uc function can be performed on them
+
+    $self->{skiprex} = '';
      
-      $self->{skiprex} = '';
-     
-      $self->{tokenrex} = qr/(\p{IsAlpha}|\P{IsAlpha}+)/;
+    $self->{tokenrex} = qr/(\p{IsAlpha}|\P{IsAlpha}+)/;
                  
-      $self->{processtoken} =  sub { s/\P{IsAlpha}+/ /; $_ = uc $_ ; $_=Encode::encode_utf8( $_ );};
-      #the last operation ***$_=Encode::encode_utf8( $_ )*** is necessary 
-      #to go back to utf8 encoding from the internal Perl representation
-      #so that for the output the n-grams are in utf8 (encoded by encode_S though)
+    $self->{processtoken} =  sub { s/\P{IsAlpha}+/ /; $_ = uc $_ ;
+				   $_ = Encode::encode_utf8( $_ ); };
+    # the last operation ***$_=Encode::encode_utf8( $_ )*** is necessary 
+    # to go back to utf8 encoding from the internal Perl representation
+    # so that for the output the n-grams are in utf8 (encoded by encode_S though)
       
       $self->{allow_iproc} = 0;
       # allow_iproc has to be 0. Otherwise the last token in the read block will
@@ -84,8 +89,10 @@ sub new {
   elsif ($params{type} eq 'word') {
       $self->{skiprex} = qr/[^a-zA-Z0-9]+/;
       $self->{skipinsert} = ' ';
-      $self->{tokenrex} = qr/([a-zA-Z]+|(\d+(\.\d+)?|\d*\.\d+)([eE][-+]?\d+)?)/;
-      $self->{processtoken} = sub { s/(\d+(\.\d+)?|\d*\.\d+)([eE][-+]?\d+)?/<NUMBER>/ }
+      $self->{tokenrex} =
+	qr/([a-zA-Z]+|(\d+(\.\d+)?|\d*\.\d+)([eE][-+]?\d+)?)/;
+      $self->{processtoken} = sub
+	{ s/(\d+(\.\d+)?|\d*\.\d+)([eE][-+]?\d+)?/<NUMBER>/ }
   }
   else { die "unknown type: $params{type}" }
   delete($params{type});
@@ -241,6 +248,7 @@ sub process_files {
 	if (not ref($f))
 	{ open(F, "$f") or die "cannot open $f:$!"; $f1 = *F }
 	else { $f1 = $f }
+	binmode $f1;  # avoid text mode
 
 	#MJ ->
 	#put the encoding layer on the input when requested
@@ -982,7 +990,7 @@ that you used the module.
 
 Author:
 
- 2003-2017 Vlado Keselj http://web.cs.dal.ca/~vlado
+ 2003-2022 Vlado Keselj http://web.cs.dal.ca/~vlado
 
 Contributors:
 
@@ -1035,18 +1043,18 @@ A n-gram language modeling package written in C++.
 
 =item CPAN N-gram module comparison article by Ben Bullock.
 
-The page is available
-  at F<http://www.lemoda.net/perl/cpan-n-gram-modules/> gives an interesting list of
-  modules, although the review seem to be superficial and only partially correct.
-  The following modules are listed in this review:
-  Algorithm::NGram, IDS::Algorithm::Ngram, Lingua::EN::Bigram, Linuga::EN::Ngram,
-  Lingua::Gram, Lingua::Identify, Text::Mining::Algorithm::Ngram,
-  Text::Ngram, Text::Ngram::LanguageDetermine, Text::Ngramize, Ntext::Ngrams, and
-  Text::Positional::Ngram.
+This page used to be available at
+F<http://www.lemoda.net/perl/cpan-n-gram-modules/>, but it seems not to be
+available any more.  It included a list of the following modules:
+Algorithm::NGram, IDS::Algorithm::Ngram, Lingua::EN::Bigram, Linuga::EN::Ngram,
+Lingua::Gram, Lingua::Identify, Text::Mining::Algorithm::Ngram,
+Text::Ngram, Text::Ngram::LanguageDetermine, Text::Ngramize, Ntext::Ngrams, and
+Text::Positional::Ngram.
 
 =back
 
-Some links to these resources should be available at F<http://web.cs.dal.ca/~vlado/nlp>.
+Some links to these resources should be available at
+F<http://web.cs.dal.ca/~vlado/nlp>.
 
 =cut
 # $Id: $
