@@ -1,5 +1,11 @@
 #!/usr/bin/perl
 
+sub isn {
+    my $get = normalize(scalar(getfile($_[0])));
+    my $new = normalize($_[1]);
+    return is($get, $new);
+}
+
 sub getfile($) {
     my $f = shift;
     local *F;
@@ -22,6 +28,11 @@ sub normalize {
     my $r = shift;
     $r =~ s/(BEGIN OUTPUT BY Text::Ngrams version )[\d.]+/$1/;
     $r =~ s/(\s\d\.\d\d\d\d\d\d\d\d\d\d\d\d\d\d)\d*/$1/g;
+
+    # used sometimes
+    #$r =~ s/[ _]//g;
+    #$r = join("\n", sort(split(/\n/, $r)));
+
     return $r;
 }
 
